@@ -1,32 +1,32 @@
 from __future__ import annotations
 import os
 from shutil import which
-from subprocess import getoutput
+import subprocess
 from json import dumps, loads
 from functools import wraps
 from timeit import default_timer
-from pkg_resources import get_distribution
 import logging
 
-__version__ = get_distribution('ripgrepy').version
 
 
 def _logger(func):
     """
     Logger decorator
     """
+
     @wraps(func)
     def l(*args, **kwargs):
         try:
             start = default_timer()
             o = func(*args, **kwargs)
             end = default_timer()
-            rt = str(round(end - start, 4)) + ' seconds'
-            logging.debug(f'{func.__name__} runtime {rt}')
+            rt = str(round(end - start, 4)) + " seconds"
+            logging.debug(f"{func.__name__} runtime {rt}")
             return o
         except:
-            logging.exception('')
+            logging.exception("")
             raise
+
     return l
 
 
@@ -43,15 +43,15 @@ class RipGrepOut(object):
     @_logger
     def as_dict(self) -> list:
         """
-        Returns an array of objects with the match. The objects include 
-        file path, line number and matched value. This is in addition to the 
+        Returns an array of objects with the match. The objects include
+        file path, line number and matched value. This is in addition to the
         --json that can be passed to ripgrep and is designed for simple ripgrep use
 
         :return: Array of matched objects
         :rtype: list
 
         The following is an example of the dict output.
-        
+
         >>> [{'data': {'absolute_offset': 12,
         >>>   'line_number': 3,
         >>>   'lines': {'text': 'teststring\\n'},
@@ -59,13 +59,13 @@ class RipGrepOut(object):
         >>>   'submatches': [{'end': 4, 'match': {'text': 'test'}, 'start': 0}]},
         >>> 'type': 'match'}]
         """
-        if '--json' not in self.command:
-            raise TypeError('To use as_dict, use the json() method')
+        if "--json" not in self.command:
+            raise TypeError("To use as_dict, use the json() method")
         out = self._output.splitlines()
         holder = []
         for line in out:
             data = loads(line)
-            if data['type'] == 'match':
+            if data["type"] == "match":
                 holder.append(data)
         return holder
 
@@ -73,19 +73,19 @@ class RipGrepOut(object):
     @_logger
     def as_json(self) -> str:
         """
-        Returns the output as a JSON object. This is in addition to the 
+        Returns the output as a JSON object. This is in addition to the
         --json that can be passed to ripgrep and is designed for simple ripgrep use
 
         :return: JSON object
         :rtype: str
         """
-        if '--json' not in self.command:
-            raise TypeError('To use as_dict, use the json() method')
+        if "--json" not in self.command:
+            raise TypeError("To use as_json, use the json() method")
         out = self._output.splitlines()
         holder = []
         for line in out:
             data = loads(line)
-            if data['type'] == 'match':
+            if data["type"] == "match":
                 holder.append(data)
         return dumps(holder)
 
@@ -119,8 +119,8 @@ class Ripgrepy(object):
     :raises RipGrepNotFound: Error if path to ripgrep could not be resolved
     """
 
-    def __init__(self, regex_pattern: str, path: str, rg_path: str='rg'):
-        self.regex_pattern = f'"{regex_pattern}"'
+    def __init__(self, regex_pattern: str, path: str, rg_path: str = "rg"):
+        self.regex_pattern = regex_pattern
         self.path = os.path.expanduser(path)
         self._output = None
         self._rg_path = rg_path
@@ -128,7 +128,7 @@ class Ripgrepy(object):
         self.command = [self._rg_path]
 
         if which(self._rg_path) is None:
-            raise RipGrepNotFound('ripgrep not found')
+            raise RipGrepNotFound("ripgrep not found")
 
         # short syntax mapping
         #: Short syntax for byte_offset
@@ -177,8 +177,8 @@ class Ripgrepy(object):
         self.P = self.pcre2
         #: Short syntax for pretty
         self.p = self.pretty
-        #: Short syntax for quite
-        self.q = self.quite
+        #: Short syntax for quiet
+        self.q = self.quiet
         #: Short syntax for regexp
         self.e = self.regexp
         #: Short syntax for replace
@@ -203,17 +203,20 @@ class Ripgrepy(object):
         self.run_rg = self.run
 
     @_logger
-    def run(self) -> Ripgrepy:
+    def run(self) -> RipGrepOut:
         """
         Returns an instace of the Ripgrepy object
 
         :return: self
-        :rtype: Ripgrepy
+        :rtype: RipGrepOut
         """
         self.command.append(self.regex_pattern)
         self.command.append(self.path)
-        self.command = ' '.join(self.command)
-        self._output = getoutput(self.command)
+        output = subprocess.run(self.command, capture_output=True)
+        if output.returncode == 0:
+            self._output = output.stdout.decode('UTF-8')
+        else:
+            self._output = output.stderr.decode('UTF-8')
         return RipGrepOut(self._output, self.command)
 
     @_logger
@@ -238,7 +241,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--after-context {number}')
+        self.command.append("--after-context")
+        self.command.append(str(number))
         return self
 
     @_logger
@@ -253,7 +257,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--before-context {number}')
+        self.command.append("--before-context")
+        self.command.append(str(number))
         return self
 
     @_logger
@@ -272,7 +277,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--context {number}')
+        self.command.append("--context")
+        self.command.append(str(number))
         return self
 
     @_logger
@@ -312,7 +318,7 @@ class Ripgrepy(object):
         This flag can be disabled with --no-binary. It overrides the
         -a/--text flag.
         """
-        self.command.append('--binary')
+        self.command.append("--binary")
         return self
 
     @_logger
@@ -350,7 +356,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--auto-hybrid-regex')
+        self.command.append("--auto-hybrid-regex")
         return self
 
     @_logger
@@ -373,7 +379,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--block-buffered')
+        self.command.append("--block-buffered")
         return self
 
     @_logger
@@ -392,7 +398,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--byte-offset')
+        self.command.append("--byte-offset")
         return self
 
     @_logger
@@ -405,7 +411,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--case-sensitive')
+        self.command.append("--case-sensitive")
         return self
 
     @_logger
@@ -428,7 +434,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--count-matches')
+        self.command.append("--count-matches")
         return self
 
     @_logger
@@ -449,7 +455,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--crlf')
+        self.command.append("--crlf")
         return self
 
     @_logger
@@ -468,7 +474,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--debug')
+        self.command.append("--debug")
         return self
 
     @_logger
@@ -487,7 +493,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--dfa-size-limit "{num_suffix}"')
+        self.command.append('--dfa-size-limit')
+        self.command.append(str(num_suffix))
         return self
 
     @_logger
@@ -516,7 +523,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--encoding "{encoding}"')
+        self.command.append('--encoding')
+        self.command.append(encoding)
         return self
 
     @_logger
@@ -536,7 +544,8 @@ class Ripgrepy(object):
         :return: [description]
         :rtype: Ripgrepy
         """
-        self.command.append(f'--file "{pattern}"')
+        self.command.append('--file')
+        self.command.append(pattern)
         return self
 
     @_logger
@@ -549,7 +558,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--files')
+        self.command.append("--files")
         return self
 
     @_logger
@@ -562,7 +571,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--files-with-matches')
+        self.command.append("--files-with-matches")
         return self
 
     @_logger
@@ -576,7 +585,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--files-without-match')
+        self.command.append("--files-without-match")
         return self
 
     @_logger
@@ -591,7 +600,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--fixed-strings')
+        self.command.append("--fixed-strings")
         return self
 
     @_logger
@@ -607,7 +616,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--follow')
+        self.command.append("--follow")
         return self
 
     @_logger
@@ -623,7 +632,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--glob "{glob_pattern}"')
+        self.command.append('--glob')
+        self.command.append(glob_pattern)
         return self
 
     @_logger
@@ -639,7 +649,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--hidden')
+        self.command.append("--hidden")
         return self
 
     @_logger
@@ -656,7 +666,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--iglob "{glob_pattern}"')
+        self.command.append('--iglob')
+        self.command.append(glob_pattern)
         return self
 
     @_logger
@@ -671,7 +682,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--ignore-case')
+        self.command.append("--ignore-case")
         return self
 
     @_logger
@@ -693,7 +704,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--ignore-file "{path}"')
+        self.command.append('--ignore-file')
+        self.command.append(path)
         return self
 
     @_logger
@@ -709,7 +721,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--ignore-file-case-insensitive')
+        self.command.append("--ignore-file-case-insensitive")
         return self
 
     @_logger
@@ -720,7 +732,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--invert-match')
+        self.command.append("--invert-match")
         return self
 
     @_logger
@@ -774,7 +786,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--json')
+        self.command.append("--json")
         return self
 
     @_logger
@@ -797,7 +809,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--line-buffered')
+        self.command.append("--line-buffered")
         return self
 
     @_logger
@@ -809,7 +821,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--line-number')
+        self.command.append("--line-number")
         return self
 
     @_logger
@@ -825,7 +837,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--line-regexp')
+        self.command.append("--line-regexp")
         return self
 
     @_logger
@@ -841,7 +853,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--max-columns {num}')
+        self.command.append("--max-columns")
+        self.command.append(str(num))
         return self
 
     @_logger
@@ -861,7 +874,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--max-columns-preview')
+        self.command.append("--max-columns-preview")
         return self
 
     @_logger
@@ -874,7 +887,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--max-count {num}')
+        self.command.append("--max-count")
+        self.command.append(str(num))
         return self
 
     @_logger
@@ -893,7 +907,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--max-depth {num}')
+        self.command.append("--max-depth")
+        self.command.append(str(num))
         return self
 
     @_logger
@@ -913,7 +928,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--max-filesize "{num_suffix}"')
+        self.command.append('--max-filesize')
+        self.command.append(num_suffix)
         return self
 
     @_logger
@@ -934,7 +950,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--mmap')
+        self.command.append("--mmap")
         return self
 
     @_logger
@@ -984,7 +1000,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--multiline')
+        self.command.append("--multiline")
         return self
 
     @_logger
@@ -1013,7 +1029,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--multiline-dotall')
+        self.command.append("--multiline-dotall")
         return self
 
     @_logger
@@ -1029,7 +1045,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-config')
+        self.command.append("--no-config")
         return self
 
     @_logger
@@ -1044,7 +1060,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-filename')
+        self.command.append("--no-filename")
         return self
 
     @_logger
@@ -1060,7 +1076,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-heading')
+        self.command.append("--no-heading")
         return self
 
     @_logger
@@ -1074,7 +1090,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-ignore')
+        self.command.append("--no-ignore")
         return self
 
     @_logger
@@ -1087,7 +1103,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-ignore-dot')
+        self.command.append("--no-ignore-dot")
         return self
 
     @_logger
@@ -1102,7 +1118,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-ignore-global')
+        self.command.append("--no-ignore-global")
         return self
 
     @_logger
@@ -1116,7 +1132,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-ignore-messages')
+        self.command.append("--no-ignore-messages")
         return self
 
     @_logger
@@ -1130,7 +1146,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-ignore-parent')
+        self.command.append("--no-ignore-parent")
         return self
 
     @_logger
@@ -1145,7 +1161,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-ignore-vcs')
+        self.command.append("--no-ignore-vcs")
         return self
 
     @_logger
@@ -1157,7 +1173,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-line-number')
+        self.command.append("--no-line-number")
         return self
 
     @_logger
@@ -1172,7 +1188,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-messages')
+        self.command.append("--no-messages")
         return self
 
     @_logger
@@ -1185,7 +1201,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-mmap')
+        self.command.append("--no-mmap")
         return self
 
     @_logger
@@ -1226,7 +1242,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--no-pcre2-unicode')
+        self.command.append("--no-pcre2-unicode")
         return self
 
     @_logger
@@ -1240,7 +1256,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--null')
+        self.command.append("--null")
         return self
 
     @_logger
@@ -1265,7 +1281,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--null-data')
+        self.command.append("--null-data")
         return self
 
     @_logger
@@ -1287,7 +1303,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--one-file-system')
+        self.command.append("--one-file-system")
         return self
 
     @_logger
@@ -1299,7 +1315,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--only-matching')
+        self.command.append("--only-matching")
         return self
 
     @_logger
@@ -1317,7 +1333,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--passthru')
+        self.command.append("--passthru")
         return self
 
     @_logger
@@ -1334,7 +1350,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--path-separator "{separator}"')
+        self.command.append('--path-separator')
+        self.command.append(separator)
         return self
 
     @_logger
@@ -1357,7 +1374,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--pcre2')
+        self.command.append("--pcre2")
         return self
 
     @_logger
@@ -1371,8 +1388,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.regex_pattern = ''
-        self.command.append('--pcre2-version')
+        self.regex_pattern = ""
+        self.command.append("--pcre2-version")
         return self
 
     @_logger
@@ -1430,7 +1447,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--pre "{command}"')
+        self.command.append('--pre')
+        self.command.append(command)
         return self
 
     @_logger
@@ -1464,7 +1482,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--pre-glob "{glob}"')
+        self.command.append('--pre-glob')
+        self.command.append(glob)
         return self
 
     @_logger
@@ -1478,11 +1497,11 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--pretty')
+        self.command.append("--pretty")
         return self
 
     @_logger
-    def quite(self) -> Ripgrepy:
+    def quiet(self) -> Ripgrepy:
         """
         Do not print anything to stdout. If a match is found in a file,
         then ripgrep will stop searching. This is useful when ripgrep is
@@ -1495,7 +1514,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--quite')
+        self.command.append("--quiet")
         return self
 
     @_logger
@@ -1512,7 +1531,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--regex-size-limit "{num_suffix}"')
+        self.command.append('--regex-size-limit')
+        self.command.append(num_suffix)
         return self
 
     @_logger
@@ -1538,8 +1558,9 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.regex_pattern = ''
-        self.command.append(f'--regexp "{pattern}"')
+        self.regex_pattern = ""
+        self.command.append('--regexp')
+        self.command.append(pattern)
         return self
 
     @_logger
@@ -1563,7 +1584,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--replace \'{replacement_text}\'')
+        self.command.append("--replace")
+        self.command.append(replacement_text)
         return self
 
     @_logger
@@ -1578,7 +1600,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--search-zip')
+        self.command.append("--search-zip")
         return self
 
     @_logger
@@ -1592,7 +1614,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--smart-case')
+        self.command.append("--smart-case")
         return self
 
     @_logger
@@ -1623,7 +1645,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--sort "{sort_by}"')
+        self.command.append('--sort')
+        self.command.append(sort_by)
         return self
 
     @_logger
@@ -1654,7 +1677,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--sortr "{sort_by}"')
+        self.command.append('--sortr')
+        self.command.append(sort_by)
         return self
 
     @_logger
@@ -1676,7 +1700,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--stats')
+        self.command.append("--stats")
         return self
 
     @_logger
@@ -1701,7 +1725,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--text')
+        self.command.append("--text")
         return self
 
     @_logger
@@ -1716,7 +1740,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--threads {num}')
+        self.command.append("--threads")
+        self.command.append(str(num))
         return self
 
     @_logger
@@ -1730,7 +1755,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--trim')
+        self.command.append("--trim")
         return self
 
     @_logger
@@ -1744,7 +1769,8 @@ class Ripgrepy(object):
         :return: [description]
         :rtype: Ripgrepy
         """
-        self.command.append(f'--type "{type_pattern}"')
+        self.command.append('--type')
+        self.command.append(type_pattern)
         return self
 
     @_logger
@@ -1784,7 +1810,8 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append(f'--type-add "{type_spec}"')
+        self.command.append('--type-add')
+        self.command.append(type_spec)
         return self
 
     @_logger
@@ -1800,7 +1827,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--type-clear')
+        self.command.append("--type-clear")
         return self
 
     @_logger
@@ -1811,9 +1838,9 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.regex_pattern = ''
-        self.path = ''
-        self.command.append('--type-list')
+        self.regex_pattern = ""
+        self.path = ""
+        self.command.append("--type-list")
         return self
 
     @_logger
@@ -1827,7 +1854,8 @@ class Ripgrepy(object):
         :return: [description]
         :rtype: Ripgrepy
         """
-        self.command.append(f'--type-not "{type_pattern}"')
+        self.command.append('--type-not')
+        self.command.append(type_pattern)
         return self
 
     @_logger
@@ -1843,7 +1871,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--unrestricted')
+        self.command.append("--unrestricted")
         return self
 
     @_logger
@@ -1856,7 +1884,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--vimgrep')
+        self.command.append("--vimgrep")
         return self
 
     @_logger
@@ -1873,7 +1901,7 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--with-filename')
+        self.command.append("--with-filename")
         return self
 
     @_logger
@@ -1888,5 +1916,85 @@ class Ripgrepy(object):
         :return: self
         :rtype: Ripgrepy
         """
-        self.command.append('--word-regexp')
+        self.command.append("--word-regexp")
+        return self
+
+    ### Options for version 12 of ripgrep
+    @_logger
+    def no_unicode(self) -> Ripgrepy:
+        """
+        By default, ripgrep will enable "Unicode mode" in all of its
+        regexes. This has a number of consequences:
+
+        ·   . will only match valid UTF-8 encoded scalar values.
+
+        ·   Classes like \w, \s, \d are all Unicode aware and much bigger
+            than their ASCII only versions.
+
+        ·   Case insensitive matching will use Unicode case folding.
+
+        ·   A large array of classes like \p{Emoji} are available.
+
+        ·   Word boundaries (\\b and \B) use the Unicode definition of a
+            word character.
+
+            In some cases it can be desirable to turn these things off. The
+            --no-unicode flag will do exactly that.
+
+            For PCRE2 specifically, Unicode mode represents a critical
+            trade off in the user experience of ripgrep. In particular,
+            unlike the default regex engine, PCRE2 does not support the
+            ability to search possibly invalid UTF-8 with Unicode features
+            enabled. Instead, PCRE2 requires that everything it searches
+            when Unicode mode is enabled is valid UTF-8. (Or valid
+            UTF-16/UTF-32, but for the purposes of ripgrep, we only discuss
+            UTF-8.) This means that if you have PCRE2's Unicode mode
+            enabled and you attempt to search invalid UTF-8, then the
+            search for that file will halt and print an error. For this
+            reason, when PCRE2's Unicode mode is enabled, ripgrep will
+            automatically "fix" invalid UTF-8 sequences by replacing them
+            with the Unicode replacement codepoint. This penalty does not
+            occur when using the default regex engine.
+
+            If you would rather see the encoding errors surfaced by PCRE2
+            when Unicode mode is enabled, then pass the --no-encoding flag
+            to disable all transcoding.
+
+            The --no-unicode flag can be disabled with --unicode. Note that
+            --no-pcre2-unicode and --pcre2-unicode are aliases for
+            --no-unicode and --unicode, respectively.
+
+        :return: self
+        :rtype: Ripgrepy
+        """
+        self.command.append("--no-unicode")
+        return self
+
+    @_logger
+    def engine(self, engine: str) -> Ripgrepy:
+        """
+        Specify which regular expression engine to use. When you choose a
+        regex engine, it applies that choice for every regex provided to
+        ripgrep (e.g., via multiple -e/--regexp or -f/--file flags).
+
+        Accepted values are default, pcre2, or auto.
+
+        The default value is default, which is the fastest and should be
+        good for most use cases. The pcre2 engine is generally useful when
+        you want to use features such as look-around or backreferences.
+        auto will dynamically choose between supported regex engines
+        depending on the features used in a pattern on a best effort basis.
+
+        Note that the pcre2 engine is an optional ripgrep feature. If PCRE2
+        wasn't including in your build of ripgrep, then using this flag
+        will result in ripgrep printing an error message and exiting.
+
+        This overrides previous uses of --pcre2 and --auto-hybrid-regex
+        flags.
+
+        :return: self
+        :rtype: Ripgrepy
+        """
+        self.command.append("--engine")
+        self.command.append(engine)
         return self
